@@ -1,7 +1,7 @@
 import os
 
-from wp21_train.savers.yml_adapter import yml_adapter
-from wp21_train.parser.athena_parser import athena_parser
+from wp21_train.savers import yml_adapter
+from wp21_train.parser import athena_parser
 
 def test_athena_parser():
     test_dir = os.path.dirname(__file__)
@@ -17,13 +17,13 @@ def test_athena_parser():
     assert data    , "Parsed data are empty"
     assert meta    , "Parsed meta-data are empty"
 
-    parser_1 = athena_parser(data, meta, nevents=1000)
+    parser_1 = athena_parser(data, meta)
     
-    os.rename('config.yaml', os.path.join(tmp_dir, 'config.yaml'))
-    os.rename('environment.yaml', os.path.join(tmp_dir, 'environment.yaml'))
+    os.rename('config.yml'     , os.path.join(tmp_dir, 'config.yml'))
+    os.rename('environment.yml', os.path.join(tmp_dir, 'environment.yml'))
 
-    assert os.path.isfile(os.path.join(tmp_dir, 'config.yaml')), "config file not created"
-    assert os.path.isfile(os.path.join(tmp_dir, 'environment.yaml')), "environment file not created"
+    assert os.path.isfile(os.path.join(tmp_dir, 'config.yml')), "config file not created"
+    assert os.path.isfile(os.path.join(tmp_dir, 'environment.yml')), "environment file not created"
     
     file_name_2 = os.path.join(tmp_dir, 'info_test_file')
     adapter_2 = yml_adapter(file_name_2)
@@ -34,8 +34,7 @@ def test_athena_parser():
     assert os.path.isfile(os.path.join(tmp_dir, 'info_test_file.yml')), "info file not created"
 
 
-    os.remove(os.path.join(tmp_dir, 'config.yaml'))
-    os.remove(os.path.join(tmp_dir, 'environment.yaml'))
+    os.remove(os.path.join(tmp_dir, 'config.yml'))
+    os.remove(os.path.join(tmp_dir, 'environment.yml'))
     os.remove(os.path.join(tmp_dir, 'info_test_file.yml'))
     os.rmdir(tmp_dir)
-
