@@ -5,5 +5,6 @@ from wp21_train import parser
 from wp21_train import savers
 from wp21_train import utils
 from wp21_train import callbacks
+from wp21_train import training
 
-__all__ = ["parser", "savers", "utils", "callbacks",  "__version__"]
+__all__ = ["parser", "savers", "utils", "callbacks", "training", "__version__"]
