@@ -9,8 +9,8 @@ from wp21_train.utils.version import __version__
 class athena_parser:
 
     def __init__(self, data: dict, metadata: dict):
-        self.config = data
-        self.environment = metadata
+        self.config = data['data']
+        self.environment = metadata['meta']
 
         # inputs to the parser should be dictionaries
         # produced by an adapter
